@@ -5,8 +5,94 @@ import warnings
 #
 #*****************************************************************************
 #
-class _Parameter():
+class _Document_Methods():
+    def __init__(self, document: object,):#--------------------------------------------
+        self._document = document
+        #
+    def add_wire(self, start_xy: tuple, end_xy: tuple):
+        '''
+        Adds a wire to a schematic or system diagram
+        
+        Parameters
+        ---------- 
+        start_xy: tuple
+              Start x,y cooridnates of the wire segment
+              
+        end_xy: tuple
+              End x,y cooridnates of the wire segment     
+        '''
+        try:
+            self._document.Wires.Add(int(start_xy[0]), int(start_xy[1]), int(end_xy[0]), int(end_xy[1]))
+        except:
+            warnings.warn('Could not add wire to document')
+        #end try
+        #
+    def remove_wire(self, start_xy: tuple, end_xy: tuple):
+        '''
+        Removes a wire from a schematic or system diagram
+        
+        Parameters
+        ---------- 
+        start_xy: tuple
+              Start x,y cooridnates of the wire segment
+              
+        end_xy: tuple
+              End x,y cooridnates of the wire segment     
+        '''
+        num_wires = self._document.Wires.Count
+        wire_removed = False
+        for wire_idx in range(num_wires):
+            wire_start_x = self._document.Wires.Item(wire_idx+1).x1
+            wire_start_y = self._document.Wires.Item(wire_idx+1).y1
+            wire_end_x = self._document.Wires.Item(wire_idx+1).x2
+            wire_end_y = self._document.Wires.Item(wire_idx+1).y2
+            found_it = True
+            if wire_start_x != start_xy[0]:
+                found_it = False
+            if wire_start_y != start_xy[1]:
+                found_it = False
+            if wire_end_x != end_xy[0]:
+                found_it = False
+            if wire_end_y != end_xy[1]:
+                found_it = False
+            #end if
+            if found_it:
+                self._document.Wires.Remove(wire_idx+1)
+                wire_removed = True
+                break
+            #end if
+        #end for
+        if not wire_removed:
+            warnings.warn('Wire could not be removed')
+        #end if
+        #
+    @property
+    def wire_segments_dict(self) -> dict:
+        '''
+        returns dictionary of wire segments
+        
+        Returns
+        ---------- 
+        wire_segment_dict:
+             keys = wire segment index
+             values = tuple (start x, start y, end x, end y)
 
+        '''
+        wire_segment_dict = dict()
+        num_wires = self._document.Wires.Count
+        for wire_idx in range(num_wires):
+            wire_start_x = self._document.Wires.Item(wire_idx+1).x1
+            wire_start_y = self._document.Wires.Item(wire_idx+1).y1
+            wire_end_x = self._document.Wires.Item(wire_idx+1).x2
+            wire_end_y = self._document.Wires.Item(wire_idx+1).y2
+            wire_segment_dict[wire_idx] = (wire_start_x, wire_start_y, wire_end_x, wire_end_y)
+        #end for
+        return wire_segment_dict
+        #
+#
+#*****************************************************************************
+#
+class _Parameter():
     def __init__(self, parameter, document_type):
         self._parameter = parameter
         self._document_type = document_type
@@ -230,7 +316,32 @@ class _Element(_Parameters):
         '''set xy position'''
         self._element.x = xy_position_tuple[0]
         self._element.y = xy_position_tuple[1]
+        #
+    def element_enable(self):#------------------------------------------------------
+        self._element.Enabled = True
+        #
+    def element_disable(self):#------------------------------------------------------
+        self._element.Enabled = False
         #    
+    @property
+    def element_nodes_dict(self) -> dict:#--------------------------------------------------------
+        ''' 
+        returns dictionary of node x,y values
+        
+        Returns
+        -------
+             nodes_dict: dictionary 
+                         dictionary keys are the node numbers
+                         dictionary values are tuples with x,y values of the node
+        '''
+        nodes_dict = dict()
+        num_nodes = self._element.Nodes.Count
+        for node_idx in range(num_nodes):
+            nodes_dict[node_idx] = (self._element.Nodes[node_idx].x, self._element.Nodes[node_idx].y)
+        #end for
+        return nodes_dict
+        #
+    
 #
 #**********************************************************************************************
 #
