@@ -3,6 +3,7 @@ from pyawr_utils import vss_utils, common_utils
 from tkinter import messagebox
 import warnings
 import numpy as np
+import copy
 #
 _SystemDiagrams = vss_utils._SystemDiagrams
 _ProcessDefinitions = common_utils._ProcessDefinitions
@@ -475,6 +476,11 @@ class _Measurement(_ProcessDefinitions):
         return self._meas.Name
         #
     @property
+    def measurement_doc_source(self) -> str:#---------------------------------------------
+        '''Returns doucument source of the measurement'''
+        return self._meas.Source
+        #
+    @property
     def measurement_enabled(self) -> bool:#---------------------------------------
         return self._meas.Enabled
         #
@@ -597,8 +603,8 @@ class _Measurement(_ProcessDefinitions):
             schem = self.awrde.Project.Schematics(source_doc)
             lpf_name = schem.ProcessDefinition
         elif source_doc_type == 'System Diagram':
-            sys_diags = SystemDiagrams(self.awrde)
-            lpf_name = sys_diags.Which_LPF
+            sys_diags = _SystemDiagrams(self.awrde)
+            lpf_name = sys_diags.read_lpf_name
         #end if
         lpf_units_dict = self._project_units(lpf_name)
         #
